/*  Copyright (C) MOXA Inc. All rights reserved.

    This software is distributed under the terms of the
    MOXA License.  See the file COPYING-MOXA for details.
*/
/*
    canbus_def_lx.c

    This is for canbus configuration, including irq, memory space and bus timing.

    2009-10-15	CF Lin
		new release
	2010-10-07	WADE liang
		this file is only for LOCAL_BUS machine !
*/
#include "canbus_def.h"


/* 
 * NOTE : due to port mis-displacement, apply some adjustment 
 * irq = 0: share irq
 */
static IRQMEM gdev_irqmem[] = 
{
	{ 34, PHYSIC_BASE_MEMORY, 0x80, 0x90 },	/* fixed port */
	{ 59, PHYSIC_BASE_MEMORY, 0xA0, 0xB0 },	/* fixed port */
};


int 
driver_private_get_maxport(void)
{
   	return (int) (sizeof(gdev_irqmem)/sizeof(gdev_irqmem[0]));
}

/*	This function gets the base memory and irq 
	Inputs:
		<port> the container of chipset information
	Outputs:
		<irqm> container of a IRQMEM, base address for a hardware port, irq
	Returns:
		0 on success
*/
int
driver_private_irqmem(HWPORT *port, IRQMEM *irqm)
{
	dbg_function_in(); /* debug */
	 /* provide a IRQ/mem to the caller */
	memcpy(irqm, &gdev_irqmem[port->port_idx], sizeof(IRQMEM));

	dbg_function_out(); /* debug */
	return 0;
}

/*
*/
void
driver_priavte_free(HWPORT *port)
{
	if (port->private_data) FREE(port->private_data);
}

/*	before port initialization, this function is called for things 
	need to be taken care of
	Inputs:
		<port> the port
		<port_idx> the index of the port
	Returns:
		0 on success
*/
int
driver_private_init(HWPORT *port, unsigned int port_idx)
{
	dbg_function_in(); /* debug */
#ifndef X86
	/* this is for MOXA IA262 */
	__raw_writeb(0, EP93XX_GPIO_B_INT_ENABLE);
	__raw_writel(1, EP93XX_GPIO_B_INT_ACK);
	__raw_writeb(__raw_readb(EP93XX_GPIO_B_INT_TYPE2)|0x01, EP93XX_GPIO_B_INT_TYPE2);
	__raw_writeb(__raw_readb(EP93XX_GPIO_B_INT_TYPE1)|0x01, EP93XX_GPIO_B_INT_TYPE1);
	__raw_writeb(__raw_readb(EP93XX_GPIO_B_INT_ENABLE)|0x01, EP93XX_GPIO_B_INT_ENABLE);
#endif 
	port->private_data = MALLOC(sizeof(CANBST));
	if (port->private_data==NULL)
		return -1;
	memset(port->private_data, 0, sizeof(CANBST));
	dbg_function_out(); /* debug */
	return 0;
}
