/*  Copyright (C) MOXA Inc. All rights reserved.

    This software is distributed under the terms of the
    MOXA License.  See the file COPYING-MOXA for details.
*/
/*
    os_dependent.h

    This is a header file to distinguish OS and try to 
	melt down their difference.

    2009-10-15	CF Lin
		new release
*/
#ifndef _OS_DEPENDENT_H_
#define _OS_DEPENDENT_H_

#ifdef WIN32

#include <windows.h>
#include <ceddk.h>
#include <nkintr.h>
#include <devload.h>
#include <Winbase.h>
#include <hwcomapi.h>

#define MALLOC(s)					LocalAlloc(LPTR,s)
#define FREE(m)						LocalFree(m)
#define VALLOC(s)					VirtualAlloc(0, s, MEM_RESERVE, PAGE_NOACCESS)
#define VFREE(m, s)					VirtualFree(m, s, MEM_RELEASE)

#define copy_from_user				memcpy
#define copy_to_user				memcpy
#define msleep						Sleep

#define	spinlock_t					CRITICAL_SECTION
#define spin_lock_init				InitializeCriticalSection	
#define spin_lock					EnterCriticalSection
#define spin_unlock					LeaveCriticalSection		
#define	wait_queue_head_t			HANDLE

#define VERIFY_READ		1
#define VERIFY_WRITE	2

#define wake_up_interruptible(x)	SetEvent(*(x))
#define init_waitqueue_head(x)		{ *(x) = CreateEvent(0,FALSE,FALSE,NULL); }

/* define for ioctl used in WinCE */
#define access_ok(type,buf,size) (buf && (type==VERIFY_READ? ilen:olen) >= size)
#define local_irq_save(f) 
#define local_irq_restore(f) 

#define dbg_function_in()			DEBUGMSG(1, (TEXT("++ %s ++\n"),__FUNCTION__))
#define dbg_function_out()			DEBUGMSG(1, (TEXT("-- %s --\n"),__FUNCTION__))

unsigned char* ioremap(unsigned long vmem, unsigned int size);
void iounmap(unsigned char *mem_map);

#else /* Linux */

#include <linux/module.h>
#include <linux/version.h>
#include <linux/kernel.h>
#include <linux/pci.h>
#include <linux/interrupt.h>
#include <linux/init.h>
#include <linux/fs.h>
#include <linux/slab.h>
#include <linux/spinlock.h>
#include <asm/io.h>
#include <asm/uaccess.h>
#include <linux/vmalloc.h>
#include <linux/poll.h>
#include <linux/delay.h>

#ifndef X86
#include <asm/arch/irqs.h>
#include <sys/time.h>
#endif

#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,10)
#include <linux/config.h>
#endif
#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,12)
#define IRQF_SHARED SA_SHIRQ
#endif

#define MALLOC(s)	kmalloc(s, GFP_KERNEL);
#define FREE(m)		kfree(m)
#define VALLOC(s)	vmalloc(s)
#define VFREE(m)	vfree(m)

#ifdef DEVICE_TYPE_IO_PORT
#define mxinb		inb
#define mxoutb		outb
#define mxinw		inw
#define mxoutw		outw
#define mxinl		inl
#define mxoutl		outl
#else
#define mxinb		ioread8
#define mxoutb		iowrite8
#define mxinw		ioread16
#define mxoutw		iowrite16
#define mxinl		ioread32
#define mxoutl		iowrite32
#endif /* DEVICE_TYPE_IO_PORT */

#ifdef DEBUG
#define DEBUGMSG printk
#else
#define DEBUGMSG(a,...)
#endif

#define dbg_function_in()				DEBUGMSG("++ %s ++\n",__FUNCTION__)
#define dbg_function_out()				DEBUGMSG("-- %s --\n",__FUNCTION__)

#endif /* WIN32 */

#endif /* _OS_DEPENDENT_H_ */



